@@ -85,7 +85,7 @@ Kwave::SignalManager::SignalManager(QWidget *parent)
     m_undo_enabled(false),
     m_undo_buffer(),
     m_redo_buffer(),
-    m_undo_transaction(0),
+    m_undo_transaction(Q_NULLPTR),
     m_undo_transaction_level(0),
     m_undo_transaction_lock(QMutex::Recursive),
     m_meta_data()
@@ -122,7 +122,7 @@ Kwave::SignalManager::~SignalManager()
 int Kwave::SignalManager::loadFile(const QUrl &url)
 {
     int res = 0;
-    Kwave::FileProgress *dialog = 0;
+    Kwave::FileProgress *dialog = Q_NULLPTR;
 
     // take over the new file name, so that we have a valid signal
     // name during loading
@@ -146,7 +146,7 @@ int Kwave::SignalManager::loadFile(const QUrl &url)
     // disable undo (discards all undo/redo data)
     disableUndo();
 
-    QString mimetype = Kwave::CodecManager::whatContains(url);
+    QString mimetype = Kwave::CodecManager::mimeTypeOf(url);
     qDebug("SignalManager::loadFile(%s) - [%s]",
            DBG(url.toDisplayString()), DBG(mimetype));
     Kwave::Decoder *decoder = Kwave::CodecManager::decoder(mimetype);
@@ -184,7 +184,7 @@ int Kwave::SignalManager::loadFile(const QUrl &url)
 	if (!tracks) break;
 
 	for (track = 0; track < tracks; ++track) {
-	    Kwave::Track *t = m_signal.appendTrack(length, 0);
+            Kwave::Track *t = m_signal.appendTrack(length, Q_NULLPTR);
 	    Q_ASSERT(t);
 	    if (!t || (t->length() != length)) {
 		qWarning("SignalManager::loadFile: out of memory");
@@ -331,7 +331,7 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
     }
 
     QString mimetype_name;
-    mimetype_name = Kwave::CodecManager::whatContains(url);
+    mimetype_name = Kwave::CodecManager::mimeTypeOf(url);
     qDebug("SignalManager::save(%s) - [%s] (%d bit, selection=%d)",
 	DBG(url.toDisplayString()), DBG(mimetype_name), bits, selection);
 
@@ -456,7 +456,7 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 	}
 
 	delete encoder;
-	encoder = 0;
+        encoder = Q_NULLPTR;
 
 	if (dialog) {
 	    qApp->processEvents();
@@ -468,7 +468,7 @@ int Kwave::SignalManager::save(const QUrl &url, bool selection)
 		res = -EINTR;
 	    }
 	    delete dialog;
-	    dialog = 0;
+            dialog = Q_NULLPTR;
 	}
     } else {
 	Kwave::MessageBox::error(m_parent_widget,
@@ -513,7 +513,7 @@ void Kwave::SignalManager::newSignal(sample_index_t samples, double rate,
 
     // add all empty tracks
     while (tracks) {
-	m_signal.appendTrack(samples, 0);
+        m_signal.appendTrack(samples, Q_NULLPTR);
 	tracks--;
     }
 
@@ -924,7 +924,7 @@ void Kwave::SignalManager::insertTrack(unsigned int index)
 
     if (index >= count) {
 	// do an "append"
-	m_signal.appendTrack(len, 0);
+        m_signal.appendTrack(len, Q_NULLPTR);
     } else {
 	if (m_undo_enabled) {
 	    // undo action for the corresponding meta data change
@@ -940,7 +940,7 @@ void Kwave::SignalManager::insertTrack(unsigned int index)
 	m_meta_data.insertTrack(index);
 
 	// insert into the list
-	m_signal.insertTrack(index, len, 0);
+        m_signal.insertTrack(index, len, Q_NULLPTR);
     }
 
     // remember the last length
@@ -1242,7 +1242,7 @@ void Kwave::SignalManager::startUndoTransaction(const QString &name)
 	// undo actions
 	if (!m_undo_manager.startUndoTransaction(m_undo_transaction)) {
 	    delete m_undo_transaction;
-	    m_undo_transaction = 0;
+            m_undo_transaction = Q_NULLPTR;
 	}
 
 	// if it is the start of the transaction, also create one
@@ -1255,7 +1255,7 @@ void Kwave::SignalManager::startUndoTransaction(const QString &name)
 	    // out of memory
 	    delete selection;
 	    delete m_undo_transaction;
-	    m_undo_transaction = 0;
+            m_undo_transaction = Q_NULLPTR;
 	}
     }
 }
@@ -1297,14 +1297,14 @@ void Kwave::SignalManager::closeUndoTransaction()
 			delete undo_action;
 		    }
 		    delete m_undo_transaction;
-		    m_undo_transaction = 0;
+                    m_undo_transaction = Q_NULLPTR;
 		} else {
 		    m_undo_buffer.append(m_undo_transaction);
 		}
 	    } else {
 		qDebug("SignalManager::closeUndoTransaction(): empty");
 		delete m_undo_transaction;
-		m_undo_transaction = 0;
+                m_undo_transaction = Q_NULLPTR;
 	    }
 	}
 
@@ -1314,7 +1314,7 @@ void Kwave::SignalManager::closeUndoTransaction()
 
 	// declare the current transaction as "closed"
 	rememberCurrentSelection();
-	m_undo_transaction = 0;
+        m_undo_transaction = Q_NULLPTR;
 	emitUndoRedoInfo();
     }
 }
@@ -1583,7 +1583,7 @@ void Kwave::SignalManager::undo()
     qint64 undo_limit = Kwave::MemoryManager::instance().undoLimit() << 20;
     qint64 redo_size = undo_transaction->redoSize();
     qint64 undo_size = undo_transaction->undoSize();
-    Kwave::UndoTransaction *redo_transaction = 0;
+    Kwave::UndoTransaction *redo_transaction = Q_NULLPTR;
     if ((redo_size > undo_size) && (redo_size - undo_size > undo_limit)) {
 	// not enough memory for redo
 	qWarning("SignalManager::undo(): not enough memory for redo !");
@@ -1619,7 +1619,7 @@ void Kwave::SignalManager::undo()
 	if (!undo_action) continue;
 
 	// execute the undo operation
-	redo_action = undo_action->undo(*this, (redo_transaction != 0));
+        redo_action = undo_action->undo(*this, (redo_transaction != Q_NULLPTR));
 
 	// remove the old undo action if no longer used
 	if (redo_action != undo_action) {
@@ -1645,7 +1645,7 @@ void Kwave::SignalManager::undo()
 	// if there is no redo action -> no redo possible
 	qWarning("SignalManager::undo(): no redo possible");
 	delete redo_transaction;
-	redo_transaction = 0;
+        redo_transaction = Q_NULLPTR;
     }
 
     // check whether the selection has changed, if yes: put a undo action
@@ -1724,7 +1724,7 @@ void Kwave::SignalManager::redo()
     qint64 undo_limit = Kwave::MemoryManager::instance().undoLimit() << 20;
     qint64 undo_size = redo_transaction->undoSize();
     qint64 redo_size = redo_transaction->redoSize();
-    Kwave::UndoTransaction *undo_transaction = 0;
+    Kwave::UndoTransaction *undo_transaction = Q_NULLPTR;
     if ((undo_size > redo_size) && (undo_size - redo_size > undo_limit)) {
 	// not enough memory for undo
 	qWarning("SignalManager::redo(): not enough memory for undo !");
@@ -1764,7 +1764,7 @@ void Kwave::SignalManager::redo()
 	Q_ASSERT(redo_action);
 	if (!redo_action) continue;
 	modified |= redo_transaction->containsModification();
-	undo_action = redo_action->undo(*this, (undo_transaction != 0));
+        undo_action = redo_action->undo(*this, (undo_transaction != Q_NULLPTR));
 
 	// remove the old redo action if no longer used
 	if (redo_action != undo_action) {
