@@ -107,7 +107,7 @@ void Kwave::DebugPlugin::load(QStringList &params)
 //***************************************************************************
 QStringList *Kwave::DebugPlugin::setup(QStringList &params)
 {
-    if (params.count() < 1) return 0;
+    if (params.count() < 1) return Q_NULLPTR;
 
     QString command = params.first();
     QString action = i18n("Debug (%1)", command);
@@ -119,12 +119,12 @@ QStringList *Kwave::DebugPlugin::setup(QStringList &params)
     if (command == _("dump_windows")) {
 	dump_children(parentWidget(), _(""));
     } else if (command == _("window:click")) {
-	if (params.count() != 4) return 0;
+        if (params.count() != 4) return Q_NULLPTR;
 	QString    class_name = params[1];
 	QWidget   *widget     = findWidget(class_name.toUtf8().constData());
 	unsigned int x        = params[2].toUInt();
 	unsigned int y        = params[3].toUInt();
-	if (!widget) return 0;
+        if (!widget) return Q_NULLPTR;
 
 	QMouseEvent *press_event =
 	    new QMouseEvent(QEvent::MouseButtonPress,
@@ -140,21 +140,21 @@ QStringList *Kwave::DebugPlugin::setup(QStringList &params)
 		Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
 	QCoreApplication::postEvent(widget, release_event);
     } else if (command == _("window:close")) {
-	if (params.count() != 2) return 0;
+        if (params.count() != 2) return Q_NULLPTR;
 	QString    class_name = params[1];
 	QWidget   *widget     = findWidget(class_name.toUtf8().constData());
 
 	qDebug("close window '%s' [%p]",
 	    DBG(class_name), static_cast<void *>(widget));
-	if (!widget) return 0;
+        if (!widget) return Q_NULLPTR;
 	widget->close();
     } else if (command == _("window:mousemove")) {
-	if (params.count() != 4) return 0;
+        if (params.count() != 4) return Q_NULLPTR;
 	QString    class_name = params[1];
 	QWidget   *widget     = findWidget(class_name.toUtf8().constData());
 	unsigned int x        = params[2].toUInt();
 	unsigned int y        = params[3].toUInt();
-	if (!widget) return 0;
+        if (!widget) return Q_NULLPTR;
 
 	QMouseEvent *move_event =
 	    new QMouseEvent(QEvent::MouseMove,
@@ -163,18 +163,18 @@ QStringList *Kwave::DebugPlugin::setup(QStringList &params)
 		Qt::NoButton, Qt::NoButton, Qt::NoModifier);
 	QCoreApplication::postEvent(widget, move_event);
     } else if (command == _("window:resize")) {
-	if (params.count() != 4) return 0;
+        if (params.count() != 4) return Q_NULLPTR;
 	QString    class_name = params[1];
 	QWidget   *widget     = findWidget(class_name.toUtf8().constData());
 	unsigned int width    = params[2].toUInt();
 	unsigned int height   = params[3].toUInt();
-	if (!widget) return 0;
+        if (!widget) return Q_NULLPTR;
 	widget->resize(width, height);
     } else if (command == _("window:screenshot")) {
-	if (params.count() != 3) return 0;
+        if (params.count() != 3) return Q_NULLPTR;
 	screenshot(params[1].toUtf8(), params[2]);
     } else if (command == _("window:sendkey")) {
-	if (params.count() != 3) return 0;
+        if (params.count() != 3) return Q_NULLPTR;
 	QString    class_name = params[1];
 	QString    key_name   = params[2];
 	QWidget   *widget     = findWidget(class_name.toUtf8().constData());
@@ -186,7 +186,7 @@ QStringList *Kwave::DebugPlugin::setup(QStringList &params)
 	qDebug("send key '%s' [0x%08X:0x%08X] to '%s' [%p]",
 	       DBG(key_name), static_cast<int>(key_modifiers), key_code,
 	       DBG(class_name), static_cast<void *>(widget));
-	if (!widget) return 0;
+        if (!widget) return Q_NULLPTR;
 
 	// make sure that the widget gets the focus
 	widget->activateWindow();
@@ -300,7 +300,7 @@ void Kwave::DebugPlugin::run(QStringList params)
 	return;
     }
 
-    Kwave::MultiTrackWriter *writers = 0;
+    Kwave::MultiTrackWriter *writers = Q_NULLPTR;
 
     if (make_new_track) {
 	// append a new track
@@ -406,7 +406,7 @@ void Kwave::DebugPlugin::dump_children(const QObject *obj,
 QWidget *Kwave::DebugPlugin::findWidget(const char *class_name) const
 {
     QObject *obj = findObject(parentWidget(), class_name);
-    if (!obj) return 0;
+    if (!obj) return Q_NULLPTR;
     return qobject_cast<QWidget *>(obj);
 }
 
@@ -414,7 +414,7 @@ QWidget *Kwave::DebugPlugin::findWidget(const char *class_name) const
 QObject *Kwave::DebugPlugin::findObject(QObject *obj,
                                         const char *class_name) const
 {
-    if (!obj) return 0;
+    if (!obj) return Q_NULLPTR;
     const char *obj_class_name = obj->metaObject()->className();
     if (strcmp(class_name, obj_class_name) == 0)
 	return obj;
@@ -424,7 +424,7 @@ QObject *Kwave::DebugPlugin::findObject(QObject *obj,
 	if (result) return result; // first match -> found
     }
 
-    return 0; // nothing found
+    return Q_NULLPTR; // nothing found
 }
 
 //***************************************************************************
